<TS version="2.1" language="si">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation type="unfinished">ලිපිනය හෝ නම්පත සංශෝධනයට දකුණු බොත්තම  ඔබන්න</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation type="unfinished">නව ලිපිනයක් සාදන්න</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished">&amp;නව</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation type="unfinished">තෝරාගෙන ඇති ලිපිනය පද්ධතියේ පසුරු පුවරුවට පිටපත් කරන්න</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished">&amp;පිටපත්</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished">වස&amp;න්න</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation type="unfinished">තේරූ ලිපිනය ලේඛනයෙන් මකන්න</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation type="unfinished">සෙවීමට ලිපිනය හෝ නම්පත යොදන්න</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">වත්මන් පටියෙයි දත්ත ගොනුවකට නිර්යාත කරන්න</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;නිර්යාතය</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished">&amp;මකන්න</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation type="unfinished">කාසි යැවිය යුතු ලිපිනය තෝරන්න</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation type="unfinished">කාසි ලැබිය යුතු ලිපිනය තෝරන්න</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation type="unfinished">තෝ&amp;රන්න</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation type="unfinished">යවන ලිපින</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation type="unfinished">ලැබෙන ලිපින</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation type="unfinished">මේ ඔබගේ ගෙවීම් යැවීම සඳහා වන බිට්කොයින් ලිපින වේ. කාසි යැවීමට පෙර සෑම විටම මුදල සහ ලැබීමේ ලිපිනය පරීක්‍ෂා කරන්න.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation type="unfinished">&amp;ලිපිනයෙහි පිටපතක්</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation type="unfinished">නම්පතෙහි &amp;පිටපතක්</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished">&amp;සංස්කරණය</translation>
    </message>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">අල්පවිරාම යෙදූ ගොනුව</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <extracomment>An error message. %1 is a stand-in argument for the name of the file we attempted to save to.</extracomment>
        <translation type="unfinished">ලිපින ලැයිස්තුව %1 ට සුරැකීමට උත්සාහ කිරීමේදී දෝෂයක් ඇතිවිය. කරුණාකර නැවත උත්සාහ කරන්න.</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">නිර්යාතයට අසමත් විය</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">නම්පත</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">ලිපිනය</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(නම්පතක් නැත)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation type="unfinished">මුරපද කවුළුව</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation type="unfinished">මුරපදය ඇතුල් කරන්න</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation type="unfinished">නව මුරපදය</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation type="unfinished">නව මුරපදය නැවත ඇතුලත් කරන්න</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation type="unfinished">මුරපදය පෙන්වන්න</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation type="unfinished">පසුම්බිය සංකේතනය</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation type="unfinished">පසුම්බිය අගුළු ඇරීමේ මෙම ක්‍රියාවලියට ඔබේ පසුම්බියේ මුරපදය අවශ්‍ය වේ.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation type="unfinished">පසුම්බිය අගුළු අරින්න</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation type="unfinished">මුරපදය වෙනස් කරන්න</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation type="unfinished">පසුම්බි සංකේතනය තහවුරු කරන්න</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation type="unfinished">අවවාදයයි: ඔබ ඔබේ මුදල් පසුම්බිය සංකේතනය කල පසු ඔබගේ මුරපදය නැති වුවහොත්, ඔබේ  &lt;b&gt;බිට්කොයින් සියල්ලම ඔබට අහිමි වනු ඇත&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation type="unfinished">ඔබේ මුදල් පසුම්බිය සංකේතනය කිරීමේ අවශ්‍යතාව තහවුරු කරන්න?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation type="unfinished">පසුම්බිය සංකේතිතයි</translation>
    </message>
    <message>
        <source>Enter the new passphrase for the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation type="unfinished">පසුම්බිය සඳහා නව මුරපදය ඇතුළත් කරන්න.&lt;br/&gt;කරුණාකර  මුරපදය සඳහා &lt;b&gt;අහඹු අක්ෂර දහයක් හෝ වැඩි ගණනක්&lt;/b&gt;, හෝ &lt;b&gt;වචන අටක් හෝ වැඩි ගණනක්&lt;/b&gt;භාවිතා කරන්න.</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase for the wallet.</source>
        <translation type="unfinished">පසුම්බිය සඳහා පැරණි මුරපදය සහ නව මුරපදය ඇතුළත් කරන්න.</translation>
    </message>
    <message>
        <source>Remember that encrypting your wallet cannot fully protect your bitcoins from being stolen by malware infecting your computer.</source>
        <translation type="unfinished">ඔබේ මුදල් පසුම්බිය සංකේතනය කිරීමෙන් ඔබේ පරිගණකයට අනිෂ්ට මෘදුකාංග (malware) ඇතුලු වීමෙන් කෙරෙන බිට්කොයින් සොරකම් කිරීම් වලින් සම්පූර්ණයෙන්ම වැළැක්වීම කළ නොහැකි බව මතක තබා ගන්න.</translation>
    </message>
    <message>
        <source>Wallet to be encrypted</source>
        <translation type="unfinished">සංකේතනය කළ යුතු පසුම්බිය</translation>
    </message>
    <message>
        <source>Your wallet is about to be encrypted. </source>
        <translation type="unfinished">පසුම්බිය සංකේතනය කිරීමට ආසන්නයි.</translation>
    </message>
    <message>
        <source>Your wallet is now encrypted. </source>
        <translation type="unfinished">ඔබගේ මුදල් පසුම්බිය දැන් සංකේතිතයි.</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation type="unfinished">වැදගත්: ඔබගේ පසුම්බි ගොනුවෙන් ඔබ විසින් සාදන ලද පෙර උපස්ථයන්(backups) අලුතින් ජනනය කරන ලද, සංකේතනය කළ පසුම්බි ගොනුව සමඟ ප්‍රතිස්ථාපනය(replace) කළ යුතුය. ආරක්ෂක හේතූන් මත, ඔබ නව, සංකේතනය කළ පසුම්බිය භාවිතා කිරීමට පටන් ගත් වහාම සංකේතනය නොකළ පසුම්බි ගොනුවේ පෙර උපස්ථ අක්‍රීය වනු ඇත.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation type="unfinished">පසුම්බිය සංකේතනයට අසමත්!</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation type="unfinished">අභ්‍යන්තර දෝෂයක් හේතුවෙන් පසුම්බි සංකේතනය අසාර්ථක විය. ඔබගේ මුදල් පසුම්බිය සංකේතනය වී නොමැත.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation type="unfinished">සපයන ලද මුරපද නොගැලපේ.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation type="unfinished">පසුම්බියේ අගුල හැරීමට අසමත් විය</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation type="unfinished">පසුම්බිය විකේතනය සඳහා ඇතුළත් කළ මුරපදය වැරදිය.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation type="unfinished">පසුම්බි මුරපදය සාර්ථකව වෙනස් කරන ලදි.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation type="unfinished">අවවාදයයි: කැප්ස් ලොක් යතුර ක්‍රියාත්මකයි!</translation>
    </message>
</context>
<context>
    <name>BitcoinApplication</name>
    <message>
        <source>Internal error</source>
        <translation type="unfinished">අභ්‍යන්තර දෝෂයකි</translation>
    </message>
    <message>
        <source>An internal error occurred. %1 will attempt to continue safely. This is an unexpected bug which can be reported as described below.</source>
        <translation type="unfinished">අභ්‍යන්තර දෝෂයක් සිදු විය. %1 ආරක්ෂිතව ඉදිරියට යාමට උත්සාහ කරනු ඇත. මෙය පහත විස්තර කර ඇති පරිදි වාර්තා කළ හැකි අනපේක්ෂිත දෝෂයකි.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Do you want to reset settings to default values, or to abort without making changes?</source>
        <extracomment>Explanatory text shown on startup when the settings file cannot be read. Prompts user to make a choice between resetting or aborting.</extracomment>
        <translation type="unfinished">ඔබට සැකසීම් පෙරනිමි අගයන් වෙත යළි පිහිටුවීමට අවශ්‍යද, නැතහොත් වෙනස්කම් සිදු නොකර නවතා දැමීමටද?</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished">දෝෂය: %1</translation>
    </message>
    <message>
        <source>%1 didn't yet exit safely…</source>
        <translation type="unfinished">%1 තවමත් ආරක්ෂිතව පිටව ගොස් නැත ...</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation type="unfinished">නොදනී</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">අගය</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform>%n second(s)</numerusform>
            <numerusform>%n second(s)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform>%n minute(s)</numerusform>
            <numerusform>%n minute(s)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform>%n hour(s)</numerusform>
            <numerusform>%n hour(s)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform>%n day(s)</numerusform>
            <numerusform>%n day(s)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform>%n week(s)</numerusform>
            <numerusform>%n week(s)</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform>%n year(s)</numerusform>
            <numerusform>%n year(s)</numerusform>
        </translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Overview</source>
        <translation type="unfinished">&amp;දළ විශ්ලේෂණය</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation type="unfinished">ගනුදෙනු ඉතිහාසය පිරික්සන්න</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation type="unfinished">පි&amp;ටවන්න</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation type="unfinished">යෙදුම වසන්න</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation type="unfinished">%1 &amp;පිළිබඳව</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation type="unfinished">%1 ගැන තොරතුරු පෙන්වන්න</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation type="unfinished">කියුටී &amp;පිළිබඳව</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation type="unfinished">කියුටී ගැන තොරතුරු පෙන්වන්න</translation>
    </message>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">නව පසුම්බියක් සාදන්න</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation type="unfinished">&amp;හකුළන්න</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">පසුම්බිය:</translation>
    </message>
    <message>
        <source>Network activity disabled.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">ජාලයේ ක්‍රියාකාරකම අබල කර ඇත.</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation type="unfinished">බිට්කොයින් ලිපිනයකට කාසි යවන්න</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation type="unfinished">වෙනත් ස්ථානයකට පසුම්බිය උපස්ථ කරන්න</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation type="unfinished">&amp;යවන්න</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation type="unfinished">&amp;ලබන්න</translation>
    </message>
    <message>
        <source>&amp;Options…</source>
        <translation type="unfinished">&amp;විකල්ප…</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet…</source>
        <translation type="unfinished">&amp;පසුම්බිය උපස්ථය…</translation>
    </message>
    <message>
        <source>Close Wallet…</source>
        <translation type="unfinished">පසුම්බිය වසන්න…</translation>
    </message>
    <message>
        <source>Create Wallet…</source>
        <translation type="unfinished">පසුම්බිය වසන්න…</translation>
    </message>
    <message>
        <source>Close All Wallets…</source>
        <translation type="unfinished">සියළු පසුම්බි වසන්න…</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished">&amp;ගොනුව</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation type="unfinished">&amp;සැකසුම්</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished">&amp;උදව්</translation>
    </message>
    <message>
        <source>Syncing Headers (%1%)…</source>
        <translation type="unfinished">(%1%) ශ්‍රීර්ෂ සමමුහූර්ත වෙමින්…</translation>
    </message>
    <message>
        <source>Synchronizing with network…</source>
        <translation type="unfinished">ජාලය සමඟ සමමුහූර්ත වෙමින්…</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform>Processed %n block(s) of transaction history.</numerusform>
            <numerusform>Processed %n block(s) of transaction history.</numerusform>
        </translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">දෝෂයකි</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished">අවවාදය</translation>
    </message>
    <message>
        <source>Information</source>
        <translation type="unfinished">තොරතුර</translation>
    </message>
    <message>
        <source>&amp;Sending addresses</source>
        <translation type="unfinished">&amp;යවන ලිපින</translation>
    </message>
    <message>
        <source>&amp;Receiving addresses</source>
        <translation type="unfinished">&amp;ලැබෙන ලිපින</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <translation type="unfinished">පසුම්බිය බලන්න</translation>
    </message>
    <message>
        <source>Open a wallet</source>
        <translation type="unfinished">පසුම්බියක් බලන්න</translation>
    </message>
    <message>
        <source>Close wallet</source>
        <translation type="unfinished">පසුම්බිය වසන්න</translation>
    </message>
    <message>
        <source>Restore Wallet…</source>
        <extracomment>Name of the menu item that restores wallet from a backup file.</extracomment>
        <translation type="unfinished">පසුම්බිය ප්‍රතිස්ථාපනය කිරීම</translation>
    </message>
    <message>
        <source>Close all wallets</source>
        <translation type="unfinished">සියළු පසුම්බි වසන්න</translation>
    </message>
    <message>
        <source>default wallet</source>
        <translation type="unfinished">පෙරනිමි පසුම්බිය</translation>
    </message>
    <message>
        <source>Wallet Data</source>
        <extracomment>Name of the wallet data file format.</extracomment>
        <translation type="unfinished">පසුම්බියේ දත්ත</translation>
    </message>
    <message>
        <source>Restore Wallet</source>
        <extracomment>Title of pop-up window shown when the user is attempting to restore a wallet.</extracomment>
        <translation type="unfinished">පසුම්බිය ප්‍රතිස්ථාපනය කිරීම</translation>
    </message>
    <message>
        <source>Wallet Name</source>
        <extracomment>Label of the input field where the name of the wallet is entered.</extracomment>
        <translation type="unfinished">පසුම්බියේ නම</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished">&amp;කවුළුව</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation type="unfinished">විශාලනය</translation>
    </message>
    <message>
        <source>Main Window</source>
        <translation type="unfinished">ප්‍රධාන කවුළුව</translation>
    </message>
    <message>
        <source>%1 client</source>
        <translation type="unfinished">%1 අනුග්‍රාහකය</translation>
    </message>
    <message>
        <source>&amp;Hide</source>
        <translation type="unfinished">&amp;සඟවන්න</translation>
    </message>
    <message>
        <source>S&amp;how</source>
        <translation type="unfinished">පෙ&amp;න්වන්න</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform>%n active connection(s) to Bitcoin network.</numerusform>
            <numerusform>%n active connection(s) to Bitcoin network.</numerusform>
        </translation>
    </message>
    <message>
        <source>Click for more actions.</source>
        <extracomment>A substring of the tooltip. "More actions" are available via the context menu.</extracomment>
        <translation type="unfinished">තව ක්‍රියාමාර්ග සඳහා ඔබන්න.</translation>
    </message>
    <message>
        <source>Disable network activity</source>
        <extracomment>A context menu item.</extracomment>
        <translation type="unfinished">ජාලයේ ක්‍රියාකාරකම අබල කරන්න</translation>
    </message>
    <message>
        <source>Enable network activity</source>
        <extracomment>A context menu item. The network activity was disabled previously.</extracomment>
        <translation type="unfinished">ජාලයේ ක්‍රියාකාරකම සබල කරන්න</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished">දෝෂය: %1</translation>
    </message>
    <message>
        <source>Warning: %1</source>
        <translation type="unfinished">අවවාදය: %1</translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation type="unfinished">දිනය: %1
</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation type="unfinished">ගණන: %1
</translation>
    </message>
    <message>
        <source>Wallet: %1
</source>
        <translation type="unfinished">පසුම්බිය: %1
</translation>
    </message>
    <message>
        <source>Type: %1
</source>
        <translation type="unfinished">වර්ගය: %1
</translation>
    </message>
    <message>
        <source>Label: %1
</source>
        <translation type="unfinished">නම්පත: %1
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation type="unfinished">ලිපිනය: %1
</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation type="unfinished">යැවූ ගනුදෙනුව</translation>
    </message>
    <message>
        <source>Private key &lt;b&gt;disabled&lt;/b&gt;</source>
        <translation type="unfinished">පෞද්ගලික යතුර &lt;b&gt;අබලයි&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Original message:</source>
        <translation type="unfinished">මුල් පණිවිඩය:</translation>
    </message>
</context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation type="unfinished">ප්‍රමාණය:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation type="unfinished">බයිට:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">අගය:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation type="unfinished">ගාස්තුව:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">අගය</translation>
    </message>
    <message>
        <source>Received with address</source>
        <translation type="unfinished">ලිපිනය සමඟ ලැබුණි</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">දිනය</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;ලිපිනයෙහි පිටපතක්</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation type="unfinished">බයිට පිටපත් කරන්න</translation>
    </message>
    <message>
        <source>yes</source>
        <translation type="unfinished">ඔව්</translation>
    </message>
    <message>
        <source>no</source>
        <translation type="unfinished">නැත</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(නම්පතක් නැත)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation type="unfinished">(වෙනස)</translation>
    </message>
</context>
<context>
    <name>CreateWalletActivity</name>
    <message>
        <source>Create Wallet</source>
        <extracomment>Title of window indicating the progress of creation of a new wallet.</extracomment>
        <translation type="unfinished">පසුම්බිය සාදන්න</translation>
    </message>
    </context>
<context>
    <name>OpenWalletActivity</name>
    <message>
        <source>default wallet</source>
        <translation type="unfinished">පෙරනිමි පසුම්බිය</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <extracomment>Title of window indicating the progress of opening of a wallet.</extracomment>
        <translation type="unfinished">පසුම්බිය බලන්න</translation>
    </message>
    </context>
<context>
    <name>RestoreWalletActivity</name>
    <message>
        <source>Restore Wallet</source>
        <extracomment>Title of progress window which is displayed when wallets are being restored.</extracomment>
        <translation type="unfinished">පසුම්බිය ප්‍රතිස්ථාපනය කිරීම</translation>
    </message>
    <message>
        <source>Restore wallet failed</source>
        <extracomment>Title of message box which is displayed when the wallet could not be restored.</extracomment>
        <translation type="unfinished">පසුම්බිය ප්‍රතිස්ථාපනය කිරීම අසාර්ථකයි</translation>
    </message>
    <message>
        <source>Restore wallet message</source>
        <extracomment>Title of message box which is displayed when the wallet is successfully restored.</extracomment>
        <translation type="unfinished">පසුම්බිය ප්‍රතිස්ථාපනය කිරීමේ පණිවිඩය </translation>
    </message>
</context>
<context>
    <name>WalletController</name>
    <message>
        <source>Close wallet</source>
        <translation type="unfinished">පසුම්බිය වසන්න</translation>
    </message>
    <message>
        <source>Close all wallets</source>
        <translation type="unfinished">සියළු පසුම්බි වසන්න</translation>
    </message>
    </context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Create Wallet</source>
        <translation type="unfinished">පසුම්බිය සාදන්න</translation>
    </message>
    <message>
        <source>Wallet Name</source>
        <translation type="unfinished">පසුම්බියේ නම</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation type="unfinished">පසුම්බිය</translation>
    </message>
    <message>
        <source>Advanced Options</source>
        <translation type="unfinished">වැඩිදුර විකල්ප</translation>
    </message>
    <message>
        <source>Disable Private Keys</source>
        <translation type="unfinished">පෞද්ගලික යතුරු අබලකරන්න</translation>
    </message>
    <message>
        <source>Create</source>
        <translation type="unfinished">සාදන්න</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation type="unfinished">ලිපිනය සංස්කරණය</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation type="unfinished">&amp;ලිපිනය</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation type="unfinished">නව යවන ලිපිනය</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation type="unfinished">ලැබෙන ලිපිනය සංස්කරණය</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation type="unfinished">යවන ලිපිනය සංස්කරණය</translation>
    </message>
    </context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>name</source>
        <translation type="unfinished">නම</translation>
    </message>
    <message>
        <source>Cannot create data directory here.</source>
        <translation type="unfinished">මෙතැන දත්ත නාමාවලිය සෑදිය නොහැකිය.</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message>
        <source>Bitcoin</source>
        <translation type="unfinished">බිට්කොයින්</translation>
    </message>
    <message numerus="yes">
        <source>%n GB of space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform>(sufficient to restore backups %n day(s) old)</numerusform>
            <numerusform>(sufficient to restore backups %n day(s) old)</numerusform>
        </translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">දෝෂයකි</translation>
    </message>
    <message>
        <source>Welcome</source>
        <translation type="unfinished">සාදරයෙන් පිළිගනිමු</translation>
    </message>
    <message>
        <source>Welcome to %1.</source>
        <translation type="unfinished">%1 වෙත සාදරයෙන් පිළිගනිමු.</translation>
    </message>
    <message>
        <source> GB</source>
        <translation type="unfinished">ගි.බ.</translation>
    </message>
    <message>
        <source>Use the default data directory</source>
        <translation type="unfinished">පෙරනිමි දත්ත නාමාවලිය භාවිතා කරන්න</translation>
    </message>
    </context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation type="unfinished">අනුවාදය</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation type="unfinished">%1 පිළිබඳව</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Form</source>
        <translation type="unfinished">වෙතින්</translation>
    </message>
    <message>
        <source>Unknown…</source>
        <translation type="unfinished">නොදනී…</translation>
    </message>
    <message>
        <source>calculating…</source>
        <translation type="unfinished">ගණනය වෙමින්…</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation type="unfinished">සඟවන්න</translation>
    </message>
    </context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation type="unfinished">විකල්ප</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation type="unfinished">&amp;ප්‍රධාන</translation>
    </message>
    <message>
        <source>Size of &amp;database cache</source>
        <translation type="unfinished">දත්තසමුදා නිහිතයේ ප්‍රමාණය</translation>
    </message>
    <message>
        <source>Open Configuration File</source>
        <translation type="unfinished">වින්‍යාස ගොනුව විවෘතකරන්න</translation>
    </message>
    <message>
        <source>&amp;Reset Options</source>
        <translation type="unfinished">&amp;නැවත සැකසීමේ විකල්ප</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation type="unfinished">&amp;ජාලය</translation>
    </message>
    <message>
        <source>GB</source>
        <translation type="unfinished">ගි.බ.</translation>
    </message>
    <message>
        <source>MiB</source>
        <translation type="unfinished">මෙ.බ.</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation type="unfinished">ප&amp;සුම්බිය</translation>
    </message>
    <message>
        <source>Enable coin &amp;control features</source>
        <translation type="unfinished">කාසි පාලන විශේෂාංග සබලකරන්න</translation>
    </message>
    <message>
        <source>Accept connections from outside.</source>
        <translation type="unfinished">පිටතින් සම්බන්ධතා පිළිගන්න.</translation>
    </message>
    <message>
        <source>Tor</source>
        <translation type="unfinished">ටෝර්</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished">&amp;කවුළුව</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation type="unfinished">අතරු මුහුණතේ &amp;භාෂාව:</translation>
    </message>
    <message>
        <source>embedded "%1"</source>
        <translation type="unfinished">එබ්බවූ "%1"</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;හරි</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;අවලංගු</translation>
    </message>
    <message>
        <source>default</source>
        <translation type="unfinished">පෙරනිමි</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">අවලංගු</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">දෝෂයකි</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation type="unfinished">වෙතින්</translation>
    </message>
    </context>
<context>
    <name>PSBTOperationsDialog</name>
    <message>
        <source>or</source>
        <translation type="unfinished">හෝ</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Age</source>
        <extracomment>Title of Peers Table column which indicates the duration (length of time) since the peer connection started.</extracomment>
        <translation type="unfinished">වයස</translation>
    </message>
    <message>
        <source>Address</source>
        <extracomment>Title of Peers Table column which contains the IP/Onion/I2P address of the connected peer.</extracomment>
        <translation type="unfinished">ලිපිනය</translation>
    </message>
    <message>
        <source>Type</source>
        <extracomment>Title of Peers Table column which describes the type of peer connection. The "type" describes why the connection exists.</extracomment>
        <translation type="unfinished">වර්ගය</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>&amp;Copy address</source>
        <extracomment>Context menu action to copy the address of a peer.</extracomment>
        <translation type="unfinished">&amp;ලිපිනයෙහි පිටපතක්</translation>
    </message>
    <message>
        <source>To</source>
        <translation type="unfinished">වෙත</translation>
    </message>
    <message>
        <source>From</source>
        <translation type="unfinished">වෙතින්</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;ලිපිනයෙහි පිටපතක්</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">අගය:</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">පසුම්බිය:</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">දිනය</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">නම්පත</translation>
    </message>
    <message>
        <source>Message</source>
        <translation type="unfinished">පණිවිඩය</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(නම්පතක් නැත)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation type="unfinished">කාසි යවන්න</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation type="unfinished">ප්‍රමාණය:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation type="unfinished">බයිට:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">අගය:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation type="unfinished">ගාස්තුව:</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation type="unfinished">සඟවන්න</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation type="unfinished">ය&amp;වන්න</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation type="unfinished">බයිට පිටපත් කරන්න</translation>
    </message>
    <message>
        <source>%1 to '%2'</source>
        <translation type="unfinished">%1 සිට '%2'</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation type="unfinished">%1 සිට %2</translation>
    </message>
    <message>
        <source>Sign failed</source>
        <translation type="unfinished">ඇතුල් වීමට අසමත්</translation>
    </message>
    <message>
        <source>or</source>
        <translation type="unfinished">හෝ</translation>
    </message>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation type="unfinished">
            <numerusform>Estimated to begin confirmation within %n block(s).</numerusform>
            <numerusform>Estimated to begin confirmation within %n block(s).</numerusform>
        </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(නම්පතක් නැත)</translation>
    </message>
</context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signature</source>
        <translation type="unfinished">අත්සන</translation>
    </message>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    <message>
        <source>kB/s</source>
        <translation type="unfinished">කි.බ./තත්.</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Status</source>
        <translation type="unfinished">තත්වය</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">දිනය</translation>
    </message>
    <message>
        <source>Source</source>
        <translation type="unfinished">මූලාශ්‍රය</translation>
    </message>
    <message>
        <source>From</source>
        <translation type="unfinished">වෙතින්</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation type="unfinished">නොදනී</translation>
    </message>
    <message>
        <source>To</source>
        <translation type="unfinished">වෙත</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform>matures in %n more block(s)</numerusform>
            <numerusform>matures in %n more block(s)</numerusform>
        </translation>
    </message>
    <message>
        <source>Message</source>
        <translation type="unfinished">පණිවිඩය</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation type="unfinished">අදහස</translation>
    </message>
    <message>
        <source>Transaction ID</source>
        <translation type="unfinished">ගනුදෙනු හැඳු.</translation>
    </message>
    <message>
        <source>Inputs</source>
        <translation type="unfinished">ආදාන</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">අගය</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">දිනය</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">වර්ගය</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">නම්පත</translation>
    </message>
    <message>
        <source>(n/a)</source>
        <translation type="unfinished">(අ/නොවේ)</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(නම්පතක් නැත)</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation type="unfinished">ගනුදෙනු වර්ග.</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>All</source>
        <translation type="unfinished">සියල්ල</translation>
    </message>
    <message>
        <source>Today</source>
        <translation type="unfinished">අද</translation>
    </message>
    <message>
        <source>This week</source>
        <translation type="unfinished">මෙම සතිය</translation>
    </message>
    <message>
        <source>This month</source>
        <translation type="unfinished">මෙම මාසය</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation type="unfinished">පසුගිය මාසය</translation>
    </message>
    <message>
        <source>This year</source>
        <translation type="unfinished">මෙම අවුරුද්ද</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;ලිපිනයෙහි පිටපතක්</translation>
    </message>
    <message>
        <source>Copy transaction &amp;ID</source>
        <translation type="unfinished">ගනුදෙනු &amp;හැඳු. පිටපත්</translation>
    </message>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">අල්පවිරාම යෙදූ ගොනුව</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">දිනය</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">වර්ගය</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">නම්පත</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">ලිපිනය</translation>
    </message>
    <message>
        <source>ID</source>
        <translation type="unfinished">හැඳු.</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">නිර්යාතයට අසමත් විය</translation>
    </message>
    <message>
        <source>Exporting Successful</source>
        <translation type="unfinished">නිර්යාත වීම සාර්ථකයි</translation>
    </message>
    <message>
        <source>to</source>
        <translation type="unfinished">වෙත</translation>
    </message>
</context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">නව පසුම්බියක් සාදන්න</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">දෝෂයකි</translation>
    </message>
    </context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Send Coins</source>
        <translation type="unfinished">කාසි යවන්න</translation>
    </message>
    <message>
        <source>default wallet</source>
        <translation type="unfinished">පෙරනිමි පසුම්බිය</translation>
    </message>
</context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;නිර්යාතය</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">වත්මන් පටියෙයි දත්ත ගොනුවකට නිර්යාත කරන්න</translation>
    </message>
    <message>
        <source>Backup Wallet</source>
        <translation type="unfinished">පසුම්බිය උපස්ථකරන්න</translation>
    </message>
    <message>
        <source>Wallet Data</source>
        <extracomment>Name of the wallet data file format.</extracomment>
        <translation type="unfinished">පසුම්බියේ දත්ත</translation>
    </message>
    <message>
        <source>Backup Failed</source>
        <translation type="unfinished">උපස්ථ වීමට අසමත් විය</translation>
    </message>
    <message>
        <source>Backup Successful</source>
        <translation type="unfinished">උපස්ථ වීම සාර්ථකයි</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">අවලංගු</translation>
    </message>
</context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>The %s developers</source>
        <translation type="unfinished">%s සංවර්ධකයින්</translation>
    </message>
    <message>
        <source>Error creating %s</source>
        <translation type="unfinished">%s සෑදීමේ දෝෂයකි</translation>
    </message>
    <message>
        <source>Error loading %s</source>
        <translation type="unfinished">%s පූරණය වීමේ දෝෂයකි</translation>
    </message>
    <message>
        <source>Error: Unable to make a backup of your wallet</source>
        <translation type="unfinished">දෝෂය: ඔබගේ පසුම්බිය ප්‍රතිස්ථාපනය කල නොහැකි විය.</translation>
    </message>
    <message>
        <source>Importing…</source>
        <translation type="unfinished">ආයාත වෙමින්…</translation>
    </message>
    <message>
        <source>Loading wallet…</source>
        <translation type="unfinished">පසුම්බිය පූරණය වෙමින්…</translation>
    </message>
    <message>
        <source>Rescanning…</source>
        <translation type="unfinished">යළි සුපිරික්සමින්…</translation>
    </message>
    <message>
        <source>This is experimental software.</source>
        <translation type="unfinished">මෙය පර්යේෂණාත්මක මෘදුකාංගයකි.</translation>
    </message>
    <message>
        <source>Unknown address type '%s'</source>
        <translation type="unfinished">'%s' නොදන්නා ලිපින වර්ගයකි</translation>
    </message>
    <message>
        <source>Settings file could not be read</source>
        <translation type="unfinished">සැකසීම් ගොනුව කියවිය නොහැක</translation>
    </message>
    </context>
</TS>